@@ -1,13 +1,14 @@
 #ifndef GRID_CONVERT_H
 #define GRID_CONVERT_H
 
+#include <cmath>
+
 #ifdef HAVE_SINCOS
+
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
 
-#include <math.h>
-
 void sincos(double x, double *sin, double *cos);
 static inline void
 gcLLtoXYZ(double lon, double lat, double *xyz)
@@ -19,18 +20,18 @@ gcLLtoXYZ(double lon, double lat, double *xyz)
   xyz[1] = coslat * sinlon;
   xyz[2] = sinlat;
 }
-#else
 
-#include <cmath>
+#else
 
 static inline void
 gcLLtoXYZ(double lon, double lat, double *xyz)
 {
-  const auto cos_lat = std::cos(lat);
+  auto cos_lat = std::cos(lat);
   xyz[0] = cos_lat * std::cos(lon);
   xyz[1] = cos_lat * std::sin(lon);
   xyz[2] = std::sin(lat);
 }
+
 #endif
 
 #ifndef M_PI
@@ -43,7 +44,6 @@ constexpr double RAD2DEG = 180.0 / M_PI;  // conversion for rad to deg
 constexpr double DEG2RAD = M_PI / 180.0;  // conversion for deg to rad
 #endif
 
-
 static inline void
 gcLLtoXYZdeg(double lon, double lat, double *xyz)
 {
